[![Build Status](https://travis-ci.org/Murthy10/pyschieber.svg?branch=master)](https://travis-ci.org/Murthy10/pyschieber)
# pyschieber
Pyschieber is an implementation of the well known Swiss Schieber Jass game.

As OpenAI Gym provides APIs for several popular games to learn your algorithms master these games.
Pyschieber aims to offer an API in the same manner.

## API
Content will follow...

## CLI
Beside of the API, pyschieber provides a CLI client to play the funny Scheiber Jass game.
Currently your opponent will be a bot choosing a random card.

## TODO
* Implement Wies
* Enhance tests
* Enhance documentation
* Architectural refactoring
* Beautify the CLI